%-------------------------------------------------------------------------;
% Figure 1 (and Figure OA.1): Plots main variables (and the effect of 
% dividend smoothing before 1700)
%-------------------------------------------------------------------------;

clear all;
clc;
close all;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Create smoothed dividends (10-year average): nominal and real;
data(:,8)=filter(ones(10,1),1,data(:,3+a))./10;

%Determine time period: 1629-1812;
data=data((data(:,1)>=1629 & data(:,1)<=1812),:);
dates_1=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);
D_10=data(:,8);

%Define variables. Returns always based on actual dividends;
RET_1=(P(2:end)+D(2:end))./(P(1:end-1))-1;

%Dividend growth up until including 1700 based on smoothed dividends, and
%on annual dividends thereafter. Make sure that DG is always based on either
%smoothed or annual dividends.
split=find(dates_1==1700);
DG_1=[D_10(2:split)./D_10(1:split-1)-1;D(split+1:end)./D(split:end-1)-1];

%Dividend-to-price ratio based on smoothed dividends up until including 
%1699, and on annual dividends thereafter; 
DP_1=[D_10(1:split-1)./P(1:split-1);D(split:end)./P(split:end)];

%------------------;
% Figure OA.1;
%------------------;

D_smooth=[D_10(1:split);D(split+1:end)];

%Plot real dividends (levels) along with smoothed dividends.;

figure(1)
plot(D,'r--','LineWidth',1.5)
hold on;
plot(D_smooth,'b-','LineWidth',1.5)
hold on;
set(gca,'FontSize',12)
set(gca, 'XTick', 12:20:length(dates_1));
set(gca, 'XTickLabel', dates_1(12:20:length(dates_1)));
legend('Annual real dividends','Smoothed real dividends');
axis([1 length(D) 0 40]);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

%------------------;
% Figure 1;
%------------------;

%Create a fill for missing observations before 1629. For returns, add also 
%one missing observation at the beginning of each period;

fill_initial=ones(1628,1)*NaN;
fill1=ones(1,1)*NaN;

RET=[fill_initial;fill1;RET_1;fill1;RET_2;fill1;RET_34];
DG=[fill_initial;fill1;DG_1;fill1;DG_2;fill1;DG_34];
DP=[fill_initial;DP_1;DP_2;DP_34];
dates=(1:2015)';

%Create breaks for different periods;
x_1=[1813,1813];
x_2=[1871,1871];
x_3=[1945,1945];
y=[-10,10];

figure(2)
plot(x_1,y,'r--','LineWidth',1.5)
hold on;
plot(x_2,y,'r--','LineWidth',1.5)
hold on;
plot(x_3,y,'r--','LineWidth',1.5)
hold on;
plot(RET,'b','LineWidth',1.5)
set(gca,'FontSize',12)
set(gca, 'XTick', 50:50:length(dates));
set(gca, 'XTickLabel', dates(50:50:length(dates)));
axis([1630 length(RET) -0.5 0.7]);

figure(3)
plot(x_1,y,'r--','LineWidth',1.5)
hold on;
plot(x_2,y,'r--','LineWidth',1.5)
hold on;
plot(x_3,y,'r--','LineWidth',1.5)
hold on;
plot(DG,'b','LineWidth',1.5)
set(gca,'FontSize',12)
set(gca, 'XTick', 50:50:length(dates));
set(gca, 'XTickLabel', dates(50:50:length(dates)));
axis([1630 length(DG) -0.5 0.7]);

figure(4)
plot(x_1,y,'r--','LineWidth',1.5)
hold on;
plot(x_2,y,'r--','LineWidth',1.5)
hold on;
plot(x_3,y,'r--','LineWidth',1.5)
hold on;
plot(DP,'b','LineWidth',1.5)
set(gca,'FontSize',12)
set(gca, 'XTick', 50:50:length(dates));
set(gca, 'XTickLabel', dates(50:50:length(dates)));
axis([1629 length(DP) 0 0.12]);

