%-------------------------------------------------------------------------;
% Figure 2, Panel A and C: DP along with recessions and 5-year ahead 
% returns or dividend growth rates 
%-------------------------------------------------------------------------;

clear all;
clc;
close all;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Create smoothed dividends (10-year average): nominal and real;
data(:,8)=filter(ones(10,1),1,data(:,3+a))./10;

%Determine time period: 1629-1812;
data=data((data(:,1)>=1629 & data(:,1)<=1812),:);
dates_1=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);
D_10=data(:,8);

%Define variables. Returns always based on actual dividends;
RET_1=(P(2:end)+D(2:end))./(P(1:end-1))-1;

%Dividend growth up until including 1700 based on smoothed dividends, and
%on annual dividends thereafter. Make sure that DG is always based on either
%smoothed or annual dividends.
split=find(dates_1==1700);
DG_1=[D_10(2:split)./D_10(1:split-1)-1;D(split+1:end)./D(split:end-1)-1];

%Dividend-to-price ratio based on smoothed dividends up until including 
%1699, and on annual dividends thereafter; 
DP_1=[D_10(1:split-1)./P(1:split-1);D(split:end)./P(split:end)];

ret_1=log(1+RET_1);
dg_1=log(1+DG_1);
dp_1=log(DP_1);

recession_1=data(1:end,7);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

ret_2=log(1+RET_2);
dg_2=log(1+DG_2);
dp_2=log(DP_2);

recession_2=data(1:end,7);

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

ret_34=log(1+RET_34);
dg_34=log(1+DG_34);
dp_34=log(DP_34);

recession_34=data(1:end,7);

%-----------------------;
% 5-year;
%-----------------------;

RET_1_5year=((RET_1(1:end-4)+1).*(RET_1(2:end-3)+1).*(RET_1(3:end-2)+1).*(RET_1(4:end-1)+1).*(RET_1(5:end)+1))-1;
RET_2_5year=((RET_2(1:end-4)+1).*(RET_2(2:end-3)+1).*(RET_2(3:end-2)+1).*(RET_2(4:end-1)+1).*(RET_2(5:end)+1))-1;
RET_34_5year=((RET_34(1:end-4)+1).*(RET_34(2:end-3)+1).*(RET_34(3:end-2)+1).*(RET_34(4:end-1)+1).*(RET_34(5:end)+1))-1;

DG_1_5year=((DG_1(1:end-4)+1).*(DG_1(2:end-3)+1).*(DG_1(3:end-2)+1).*(DG_1(4:end-1)+1).*(DG_1(5:end)+1))-1;
DG_2_5year=((DG_2(1:end-4)+1).*(DG_2(2:end-3)+1).*(DG_2(3:end-2)+1).*(DG_2(4:end-1)+1).*(DG_2(5:end)+1))-1;
DG_34_5year=((DG_34(1:end-4)+1).*(DG_34(2:end-3)+1).*(DG_34(3:end-2)+1).*(DG_34(4:end-1)+1).*(DG_34(5:end)+1))-1;

%-------------------------------------------------------------------------;
%Plot DP along with either 5-year ahead returns or dividend growth rates;
%-------------------------------------------------------------------------;

%Create a fill for missing observations of returns and dividend growth 
%rates between the periods (as they are summed over 5 years);

fill5=ones(5,1)*NaN;

RET_5y=[RET_1_5year;fill5;RET_2_5year;fill5;RET_34_5year;fill5];
DG_5y=[DG_1_5year;fill5;DG_2_5year;fill5;DG_34_5year;fill5];
DP_5y=[DP_1;DP_2;DP_34];

dates=(1629:2015)';

%Create breaks for different periods;
x_1=[1813,1813];
x_2=[1871,1871];
x_3=[1945,1945];
y=[-10,10];

%Recessions (timing aligned with the dividend-to-price ratio);
Rec=[dates [recession_1;recession_2;recession_34]];

%Determine beginnings and endings for recessions, b and c;
a=Rec(1:end,2);
b=zeros(size(a,1),1);

for i=1:size(a,1)-1;
    if a(i)==0 & a(i+1)==1;
        b(i)=1;
    else;
        b(i)=0;
    end;
end;

%Last observation for b is always zero;

c=zeros(size(a,1),1);

for i=1:size(a,1)-1;
    if a(i)==1 & a(i+1)==0;
        c(i)=1;
    else;
        c(i)=0;
    end;
end;

%Last observation for c is the same as for a;
c(size(a,1),1)=a(size(a,1),1);

%Assign observation numbers to b and c;
d=[b c (1:(size(a,1)))'];

for i=1:size(a,1);
    if b(i)==1;
        b(i)=d(i,3);
    end;
    if c(i)==1;
        c(i)=d(i,3);
    end;
end;

d=[b c (1:(size(a,1)))'];

b=find(b>0);
c=find(c>0);

%Convert in years;
b=b+1628;
c=c+1628;

figure(1)
for i=1:size(b,1); 
    patch([b(i) c(i) c(i) b(i)],[0 0 0.14 0.14],[0.9 0.9 0.9],'EdgeColor','none')
end;
hold on

[AX,H1,H2] = plotyy(dates,DP_5y,dates,RET_5y);
ylabel(AX(1),'DP','FontSize',14) % left y-axis;
ylabel(AX(2),'5-year returns','FontSize',12) % right y-axis;
set(AX,{'ycolor'},{'b';'[0,0.5,0]'})  % Left blue, right dark green;
set(AX(1),'YLim',[0 0.14])
set(AX(1),'YTick',(0:0.02:0.14))
set(AX(2),'YLim',[-0.7 2.8])
set(AX(2),'YTick',(-0.7:0.5:3.5))
set(AX(1),'xLim',[1629 2015])
set(AX(2),'xLim',[1629 2015])
set(AX(1),'FontSize',14)
set(AX(2),'FontSize',14)
set(H1,'Linewidth',2,'Color','b');
set(H2,'Linewidth',2,'LineStyle','--','Color','[0,0.5,0]');
hold on;
plot(x_1,y,'r--','LineWidth',2)
hold on;
plot(x_2,y,'r--','LineWidth',2)
hold on;
plot(x_3,y,'r--','LineWidth',2)
hold on;

figure(2)
for i=1:size(b,1); 
    patch([b(i) c(i) c(i) b(i)],[0 0 0.14 0.14],[0.9 0.9 0.9],'EdgeColor','none')
end;
hold on

[AX,H1,H2] = plotyy(dates,DP_5y,dates,DG_5y);
ylabel(AX(1),'DP','FontSize',14) % left y-axis;
ylabel(AX(2),'5-year dividend growth rates','FontSize',12) % right y-axis;
set(AX,{'ycolor'},{'b';'[0,0.5,0]'})  % Left blue, right dark green;
set(AX(1),'YLim',[0 0.14])
set(AX(1),'YTick',(0:0.02:0.14))
set(AX(2),'YLim',[-1 1.8])
set(AX(2),'YTick',(-1:0.4:1.8))
set(AX(1),'xLim',[1629 2015])
set(AX(2),'xLim',[1629 2015])
set(AX(1),'FontSize',14)
set(AX(2),'FontSize',14)
set(H1,'Linewidth',2,'Color','b');
set(H2,'Linewidth',2,'LineStyle','--','Color','[0,0.5,0]');
hold on;
plot(x_1,y,'r--','LineWidth',2)
hold on;
plot(x_2,y,'r--','LineWidth',2)
hold on;
plot(x_3,y,'r--','LineWidth',2)
hold on;

