%-------------------------------------------------------------------------;
% Figure 3: Out-of-sample R-square for returns;
%-------------------------------------------------------------------------;

clear all;
clc;
close all;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Create smoothed dividends (10-year average): nominal and real;
data(:,8)=filter(ones(10,1),1,data(:,3+a))./10;

%Determine time period: 1629-1812;
data_l=data((data(:,1)>=1629 & data(:,1)<=1812),:);
dates_1=data_l(:,1);

%Prices and dividends;
P=data_l(:,2+a); 
D=data_l(:,3+a);
D_10=data_l(:,8);

%Define variables. Returns always based on actual dividends;
RET_1=(P(2:end)+D(2:end))./(P(1:end-1))-1;

%Dividend growth up until including 1700 based on smoothed dividends, and
%on annual dividends thereafter. Make sure that DG is always based on either
%smoothed or annual dividends.
split=find(dates_1==1700);
DG_1=[D_10(2:split)./D_10(1:split-1)-1;D(split+1:end)./D(split:end-1)-1];

%Dividend-to-price ratio based on smoothed dividends up until including 
%1699, and on annual dividends thereafter; 
DP_1=[D_10(1:split-1)./P(1:split-1);D(split:end)./P(split:end)];

ret_1=log(1+RET_1);
dg_1=log(1+DG_1);
dp_1=log(DP_1);

recession_1=data_l(1:end,7);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

ret_2=log(1+RET_2);
dg_2=log(1+DG_2);
dp_2=log(DP_2);

recession_2=data(1:end,7);

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

ret_34=log(1+RET_34);
dg_34=log(1+DG_34);
dp_34=log(DP_34);

recession_34=data(1:end,7);
   
%-------------------------------------------;
% 1-year ahead predictions;
%-------------------------------------------;

h=1;

ret_h=[ret_1;ret_2;ret_34];
dp=[dp_1(1:end-h);dp_2(1:end-h);dp_34(1:end)]; 

T = size(dp,1);

%Out-of-sample predicting;

a=72; %Starting point for expanding windows. First prediction based on the 
%value of dp in 1700;

%To store predictions;
ret_f=zeros(T-h,1); %Forecasts using a constant and dp;
ret_fc=zeros(T-h,1); %Forecasts based on a constant;

for i=a:T-h
     [b,b_std,tb,R2,AR2,error]=olsnw(ret_h(h:i-1),[ones(i-h,1) dp(1:i-h)],1,1);
     ret_f(i+h-1)=b(1,1)+b(2,1)*dp(i);
     ret_fc(i+h-1)=mean(ret_h(h:i-1));
end;

%Actual returns and predictions;
ret_a=ret_h(a+h-1:end);
ret_f=ret_f(a+h-1:end); 
ret_fc=ret_fc(a+h-1:end);

%Forecasting errors;
err_f=ret_a-ret_f;
err_fc=ret_a-ret_fc;

%Out-of-sample R-square;
R2_OOS_1y=1.-(err_f'*err_f)./(err_fc'*err_fc);
SSE_diff_1y=(cumsum(err_fc.^2)-cumsum(err_f.^2))/sum(err_fc.^2);

%-------------------------------------------;
% 3-year ahead predictions;
%-------------------------------------------;

h=3;

%Sums returns over h periods;    
ret_h_1=filter(ones(h,1),1,ret_1);
ret_h_2=filter(ones(h,1),1,ret_2);
ret_h_34=filter(ones(h,1),1,ret_34); 

ret_h=[ret_h_1;ret_h_2(h:end);ret_h_34(h:end)];
dp=[dp_1(1:end-h);dp_2(1:end-h);dp_34(1:end)]; 

T = size(dp,1);

%Out-of-sample predicting;

a=72; %Starting point for expanding windows. First prediction based on the 
%value of dp in 1700;

%To store predictions;
ret_f=zeros(T-h,1); %Forecasts using a constant and dp;
ret_fc=zeros(T-h,1); %Forecasts based on a constant;

for i=a:T-h
     [b,b_std,tb,R2,AR2,error]=olsnw(ret_h(h:i-1),[ones(i-h,1) dp(1:i-h)],1,1);
     ret_f(i+h-1)=b(1,1)+b(2,1)*dp(i);
     ret_fc(i+h-1)=mean(ret_h(h:i-1));
end;

%Actual returns and predictions;
ret_a=ret_h(a+h-1:end);
ret_f=ret_f(a+h-1:end); 
ret_fc=ret_fc(a+h-1:end);

%Forecasting errors;
err_f=ret_a-ret_f;
err_fc=ret_a-ret_fc;

%Out-of-sample R-square;
R2_OOS_3y=1.-(err_f'*err_f)./(err_fc'*err_fc);
SSE_diff_3y=(cumsum(err_fc.^2)-cumsum(err_f.^2))/sum(err_fc.^2);

%-------------------------------------------;
% 5-year ahead predictions;
%-------------------------------------------;

h=5;

%Sums returns over h periods;    
ret_h_1=filter(ones(h,1),1,ret_1);
ret_h_2=filter(ones(h,1),1,ret_2);
ret_h_34=filter(ones(h,1),1,ret_34); 

ret_h=[ret_h_1;ret_h_2(h:end);ret_h_34(h:end)];
dp=[dp_1(1:end-h);dp_2(1:end-h);dp_34(1:end)]; 

T = size(dp,1);

%Out-of-sample predicting;

a=72; %Starting point for expanding windows. First prediction based on the 
%value of dp in 1700;

%To store predictions;
ret_f=zeros(T-h,1); %Forecasts using a constant and dp;
ret_fc=zeros(T-h,1); %Forecasts based on a constant;

for i=a:T-h
     [b,b_std,tb,R2,AR2,error]=olsnw(ret_h(h:i-1),[ones(i-h,1) dp(1:i-h)],1,1);
     ret_f(i+h-1)=b(1,1)+b(2,1)*dp(i);
     ret_fc(i+h-1)=mean(ret_h(h:i-1));
end;

%Actual returns and predictions;
ret_a=ret_h(a+h-1:end);
ret_f=ret_f(a+h-1:end); 
ret_fc=ret_fc(a+h-1:end);

%Forecasting errors;
err_f=ret_a-ret_f;
err_fc=ret_a-ret_fc;

%Out-of-sample R-square;
R2_OOS_5y=1.-(err_f'*err_f)./(err_fc'*err_fc);
SSE_diff_5y=(cumsum(err_fc.^2)-cumsum(err_f.^2))/sum(err_fc.^2);

%--------------------------------------------;
% Plot cumulative SSE along with recessions;
%--------------------------------------------;

%Create a fill for missing observations of the SSE. Timing as of dp. First
%dp used in 1700, hence first SSE timed as 1700.

fill_initial=ones(1699,1)*NaN;
fill1=ones(1,1)*NaN;
fill3=ones(3,1)*NaN;
fill5=ones(5,1)*NaN;

%1-year;
h=1;
SSE_diff_1y_1=SSE_diff_1y(1:size(dp_1,1)-a-h+1);
SSE_diff_1y_2=SSE_diff_1y(size(SSE_diff_1y_1,1)+1:size(SSE_diff_1y_1,1)+1+size(dp_2,1)-h-1);
SSE_diff_1y_34=SSE_diff_1y(size(SSE_diff_1y_1,1)+size(SSE_diff_1y_2,1)+1:end);

SSE_diff_plot_1y=[fill_initial;SSE_diff_1y_1;fill1;SSE_diff_1y_2;fill1;SSE_diff_1y_34;fill1];

%3-year;
h=3;
SSE_diff_3y_1=SSE_diff_3y(1:size(dp_1,1)-a-h+1);
SSE_diff_3y_2=SSE_diff_3y(size(SSE_diff_3y_1,1)+1:size(SSE_diff_3y_1,1)+1+size(dp_2,1)-h-1);
SSE_diff_3y_34=SSE_diff_3y(size(SSE_diff_3y_1,1)+size(SSE_diff_3y_2,1)+1:end);

SSE_diff_plot_3y=[fill_initial;SSE_diff_3y_1;fill3;SSE_diff_3y_2;fill3;SSE_diff_3y_34;fill3];

%5-year;
h=5;
SSE_diff_5y_1=SSE_diff_5y(1:size(dp_1,1)-a-h+1);
SSE_diff_5y_2=SSE_diff_5y(size(SSE_diff_5y_1,1)+1:size(SSE_diff_5y_1,1)+1+size(dp_2,1)-h-1);
SSE_diff_5y_34=SSE_diff_5y(size(SSE_diff_5y_1,1)+size(SSE_diff_5y_2,1)+1:end);

SSE_diff_plot_5y=[fill_initial;SSE_diff_5y_1;fill5;SSE_diff_5y_2;fill5;SSE_diff_5y_34;fill5];

%Create breaks for different periods;
x_1=[1813,1813];
x_2=[1871,1871];
x_3=[1945,1945];
y=[-10,10];

%Add recessions (timing aligned with the dividend-to-price ratio);
dates=[dates_1;dates_2;dates_34];
Rec=[dates [recession_1;recession_2;recession_34]];

%Determine beginnings and endings for recessions, b and c;
a=Rec(1:end,2);
b=zeros(size(a,1),1);

for i=1:size(a,1)-1
    if a(i)==0 && a(i+1)==1
        b(i)=1;
    else
        b(i)=0;
    end;
end;

%Last observation for b is always zero;

c=zeros(size(a,1),1);

for i=1:size(a,1)-1
    if a(i)==1 && a(i+1)==0
        c(i)=1;
    else
        c(i)=0;
    end;
end;

%Last observation for c is the same as for a;
c(size(a,1),1)=a(size(a,1),1);

%Assign observation numbers to b and c;
d=[b c (1:(size(a,1)))'];

for i=1:size(a,1)
    if b(i)==1
        b(i)=d(i,3);
    end;
    if c(i)==1
        c(i)=d(i,3);
    end;
end;

d=[b c (1:(size(a,1)))'];

b=find(b>0);
c=find(c>0);

%Convert in years;
b=b+1628;
c=c+1628;

figure(1)
for i=1:size(b,1) 
    patch([b(i) c(i) c(i) b(i)],[-1 -1 0.1595 0.1595],[0.9 0.9 0.9],'EdgeColor','none')
end;
hold on
plot(SSE_diff_plot_1y,'b:','LineWidth',2)
plot(SSE_diff_plot_3y,'b--','LineWidth',2)
plot(SSE_diff_plot_5y,'b-','LineWidth',2)
plot(x_1,y,'r--','LineWidth',2)
hold on;
plot(x_2,y,'r--','LineWidth',2)
hold on;
plot(x_3,y,'r--','LineWidth',2)
hold on;
set(gca,'FontSize',14)
set(gca,'YLim',[0.0 0.15])
set(gca,'YTick',(0.00:0.03:0.15))
axis([1700 2015 -0.01 0.16]);

%Add a box and text boxes for 1-,3- and 5-year predictions;













