%-------------------------------------------------------------------------;
% Table 1: Summary statistics for annual data
% Results are in Tab_1_Nominal or Tab_1_Real.
%-------------------------------------------------------------------------;

clear all;
clc;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Create smoothed dividends (10-year average): nominal and real;
data(:,8)=filter(ones(10,1),1,data(:,3+a))./10;

%Determine time period: 1629-1812;
data_l=data((data(:,1)>=1629 & data(:,1)<=1812),:);
dates_1=data_l(:,1);

%Prices and dividends;
P=data_l(:,2+a); 
D=data_l(:,3+a);
D_10=data_l(:,8);

%Define variables. Returns always based on actual dividends;
RET_1=(P(2:end)+D(2:end))./(P(1:end-1))-1;

%Dividend growth up until including 1700 based on smoothed dividends, and
%on annual dividends thereafter. Make sure that DG is always based on either
%smoothed or annual dividends.
split=find(dates_1==1700);
DG_1=[D_10(2:split)./D_10(1:split-1)-1;D(split+1:end)./D(split:end-1)-1];

%Dividend-to-price ratio based on smoothed dividends up until including 
%1699, and on annual dividends thereafter; 
DP_1=[D_10(1:split-1)./P(1:split-1);D(split:end)./P(split:end)];

CPI=data_l(:,6);
Inflation_1=CPI(2:end)./CPI(1:end-1)-1;

DY_1=D(2:end)./P(1:end-1); %Dividend yield;

%--------------------------------;
% Subperiod: from 1700 onwards;
%-------------------------------;

data_s=data((data(:,1)>=1700 & data(:,1)<=1812),:);
dates_s=data_s(:,1);

%Prices and dividends;
P=data_s(:,2+a); 
D=data_s(:,3+a);

%Define variables. 
RET_1_s=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_1_s=D(2:end)./D(1:end-1)-1;
DP_1_s=D(1:end)./P(1:end);

CPI=data_s(:,6);
Inflation_1_s=CPI(2:end)./CPI(1:end-1)-1;

DY_1_s=D(2:end)./P(1:end-1); %Dividend yield;

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

CPI=data(:,6);
Inflation_2=CPI(2:end)./CPI(1:end-1)-1;

DY_2=D(2:end)./P(1:end-1); %Dividend yield;

%----------------------;
% U.S. early 1871-1945
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=1945),:);
dates_3=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_3=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_3=(D(2:end))./(D(1:end-1))-1;
DP_3=(D(1:end))./(P(1:end));

CPI=data(:,6);
Inflation_3=CPI(2:end)./CPI(1:end-1)-1;

DY_3=D(2:end)./P(1:end-1); %Dividend yield;

%------------------------;
% U.S. recent: 1945-2015
%------------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1945 & data(:,1)<=2015),:);
dates_4=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_4=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_4=(D(2:end))./(D(1:end-1))-1;
DP_4=(D(1:end))./(P(1:end));

CPI=data(:,6);
Inflation_4=CPI(2:end)./CPI(1:end-1)-1;

DY_4=D(2:end)./P(1:end-1); %Dividend yield;

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

CPI=data(:,6);
Inflation_34=CPI(2:end)./CPI(1:end-1)-1;

DY_34=D(2:end)./P(1:end-1); %Dividend yield;

%--------------------------------;
% Full-sample period: 1629-2015
%--------------------------------;

RET_full=[RET_1;RET_2;RET_34];
DY_full=[DY_1;DY_2;DY_34];
DG_full=[DG_1;DG_2;DG_34];
DP_full=[DP_1;DP_2;DP_34];
Inflation_full=[Inflation_1;Inflation_2;Inflation_34];

%---------------------------------;
% Mean risk-free rate per period;
%---------------------------------;

filename='Rf_per_period.xls';
rf=xlsread(filename);

%Rf for the full-sample period;
rf(1,6)=size(DP_1,1)/size(DP_full,1)*rf(1,1)+size(DP_2,1)/size(DP_full,1)*rf(1,3)+size(DP_3,1)/size(DP_full,1)*rf(1,4)+size(DP_4,1)/size(DP_full,1)*rf(1,5);

%-----------------------------------;
% Summary statistics;
%-----------------------------------;

%Returns;
Mean_RET=[mean(RET_1) mean(RET_1_s) mean(RET_2) mean(RET_3) mean(RET_4) mean(RET_full)];
Mean_DY=[mean(DY_1) mean(DY_1) mean(DY_2) mean(DY_3) mean(DY_4) mean(DY_full)];
DY_RET=Mean_DY./Mean_RET;
Std_RET=[std(RET_1) std(RET_1_s) std(RET_2) std(RET_3) std(RET_4) std(RET_full)];
AR_RET=[autocorr(RET_1,1) autocorr(RET_1_s,1) autocorr(RET_2,1) autocorr(RET_3,1) autocorr(RET_4,1) autocorr(RET_full,1)];
AR_RET=AR_RET(2,:);
Std_AR_RET=[1/sqrt(size(RET_1,1)) 1/sqrt(size(RET_1_s,1)) 1/sqrt(size(RET_2,1)) 1/sqrt(size(RET_3,1)) 1/sqrt(size(RET_4,1)) 1/sqrt(size(RET_full,1))];
t_AR_RET=AR_RET./Std_AR_RET;

%Risk-free rate, risk premia, and SR;
RF=rf;
RP=Mean_RET-RF;
SR=(Mean_RET-RF)./Std_RET;

Inflation=[mean(Inflation_1) mean(Inflation_1_s) mean(Inflation_2) mean(Inflation_3) mean(Inflation_4) mean(Inflation_full)];

%Dividend growth;
Mean_DG=[mean(DG_1) mean(DG_1_s) mean(DG_2) mean(DG_3) mean(DG_4) mean(DG_full)];
Std_DG=[std(DG_1) std(DG_1_s) std(DG_2) std(DG_3) std(DG_4) std(DG_full)];
AR_DG=[autocorr(DG_1,1) autocorr(DG_1_s,1) autocorr(DG_2,1) autocorr(DG_3,1) autocorr(DG_4,1) autocorr(DG_full,1)];
AR_DG=AR_DG(2,:);
Std_AR_DG=[1/sqrt(size(DG_1,1)) 1/sqrt(size(DG_1_s,1)) 1/sqrt(size(DG_2,1)) 1/sqrt(size(DG_3,1)) 1/sqrt(size(DG_4,1)) 1/sqrt(size(DG_full,1))];
t_AR_DG=AR_DG./Std_AR_DG;

%Dividend-to-price ratio;
Mean_DP=[mean(DP_1) mean(DP_1_s) mean(DP_2) mean(DP_3) mean(DP_4) mean(DP_full)];
Std_DP=[std(DP_1) std(DP_1_s) std(DP_2) std(DP_3) std(DP_4) std(DP_full)];
AR_DP=[autocorr(DP_1,1) autocorr(DP_1_s,1) autocorr(DP_2,1) autocorr(DP_3,1) autocorr(DP_4,1) autocorr(DP_full,1)];
AR_DP=AR_DP(2,:);

%Test for unit root (ADF from Spatial econometrics toolbox. All the 
%necessary codes are in subfolder 'Additional codes')

adf_DP_1=adf(DP_1,1,1);
adf_DP_1_s=adf(DP_1_s,1,1);
adf_DP_2=adf(DP_2,1,1);
adf_DP_3=adf(DP_3,1,1);
adf_DP_4=adf(DP_4,1,1);
adf_DP_full=adf(DP_full,1,1);
ADF=[adf_DP_1.adf adf_DP_1_s.adf adf_DP_2.adf adf_DP_3.adf adf_DP_4.adf adf_DP_full.adf];

%Critical values for adf; 1%, 5%, 10%;
adf_crit=[adf_DP_1.crit(1:3) adf_DP_1_s.crit(1:3) adf_DP_2.crit(1:3) adf_DP_3.crit(1:3) adf_DP_4.crit(1:3) adf_DP_full.crit(1:3)];

%----------------;
%Display results;
%----------------;

%Express the main variables in percentages;

Mean_RET=Mean_RET*100;
Std_RET=Std_RET*100;
RF=RF*100;
RP=RP*100;
Inflation=Inflation*100;
Mean_DG=Mean_DG*100;
Std_DG=Std_DG*100;
Mean_DP=Mean_DP*100;
Std_DP=Std_DP*100;

%If nominal data;
if a==0; Tab_1_Nominal=[Mean_RET;Std_RET;AR_RET;t_AR_RET;DY_RET;RF;RP;SR;Inflation;Mean_DG;Std_DG;AR_DG;t_AR_DG]
end;

%If real data;
if a==2; Tab_1_Real=[Mean_RET;Std_RET;AR_RET;t_AR_RET;DY_RET;Mean_DG;Std_DG;AR_DG;t_AR_DG;Mean_DP;Std_DP;AR_DP;ADF]
end;
