%-------------------------------------------------------------------------;
% Table 2: Return and dividend growth regressions
% Results are in Tab_2.
%-------------------------------------------------------------------------;

clear all;
clc;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Create smoothed dividends (10-year average): nominal and real;
data(:,8)=filter(ones(10,1),1,data(:,3+a))./10;

%Determine time period: 1629-1812;
data_l=data((data(:,1)>=1629 & data(:,1)<=1812),:);
dates_1=data_l(:,1);

%Prices and dividends;
P=data_l(:,2+a); 
D=data_l(:,3+a);
D_10=data_l(:,8);

%Define variables. Returns always based on actual dividends;
RET_1=(P(2:end)+D(2:end))./(P(1:end-1))-1;

%Dividend growth up until including 1700 based on smoothed dividends, and
%on annual dividends thereafter. Make sure that DG is always based on either
%smoothed or annual dividends.
split=find(dates_1==1700);
DG_1=[D_10(2:split)./D_10(1:split-1)-1;D(split+1:end)./D(split:end-1)-1];

%Dividend-to-price ratio based on smoothed dividends up until including 
%1699, and on annual dividends thereafter; 
DP_1=[D_10(1:split-1)./P(1:split-1);D(split:end)./P(split:end)];

ret_1=log(1+RET_1);
dg_1=log(1+DG_1);
dp_1=log(DP_1);

%--------------------------------;
% Subperiod: from 1700 onwards;
%-------------------------------;

data_s=data((data(:,1)>=1700 & data(:,1)<=1812),:);
dates_s=data_s(:,1);

%Prices and dividends;
P=data_s(:,2+a); 
D=data_s(:,3+a);

%Define variables. 
RET_1_s=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_1_s=D(2:end)./D(1:end-1)-1;
DP_1_s=D(1:end)./P(1:end);

ret_1_s=log(1+RET_1_s);
dg_1_s=log(1+DG_1_s);
dp_1_s=log(DP_1_s);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

ret_2=log(1+RET_2);
dg_2=log(1+DG_2);
dp_2=log(DP_2);

%----------------------;
% U.S. early 1871-1945
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-1945;
data=data((data(:,1)>=1871 & data(:,1)<=1945),:);
dates_3=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_3=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_3=(D(2:end))./(D(1:end-1))-1;
DP_3=(D(1:end))./(P(1:end));

ret_3=log(1+RET_3);
dg_3=log(1+DG_3);
dp_3=log(DP_3);

%------------------------;
% U.S. recent: 1945-2015
%------------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1945 & data(:,1)<=2015),:);
dates_4=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_4=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_4=(D(2:end))./(D(1:end-1))-1;
DP_4=(D(1:end))./(P(1:end));

ret_4=log(1+RET_4);
dg_4=log(1+DG_4);
dp_4=log(DP_4);

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

ret_34=log(1+RET_34);
dg_34=log(1+DG_34);
dp_34=log(DP_34);

%-------------------------------------------------;
% OLS estimates with a constant (NW with one lag);
%-------------------------------------------------;

%----------------------------;
% Netherlands/U.K.(1629-1812);
%----------------------------;

T = size(DP_1,1);

%Raw data;
y=RET_1;
x=[ones(T-1,1) DP_1(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,1)=[b(2,1);tb(2,1);0;R2];

y=DG_1;
x=[ones(T-1,1) DP_1(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,1)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=ret_1;
x=[ones(T-1,1) dp_1(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,1)=[b(2,1);tb(2,1);0;R2];

y=dg_1;
x=[ones(T-1,1) dp_1(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,1)=[b(2,1);tb(2,1);0;R2];

%----------------------------;
% U.K.(1813-1870);
%----------------------------;

T = size(DP_2,1);

%Raw data;
y=RET_2;
x=[ones(T-1,1) DP_2(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,2)=[b(2,1);tb(2,1);0;R2];

y=DG_2;
x=[ones(T-1,1) DP_2(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,2)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=ret_2;
x=[ones(T-1,1) dp_2(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,2)=[b(2,1);tb(2,1);0;R2];

y=dg_2;
x=[ones(T-1,1) dp_2(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,2)=[b(2,1);tb(2,1);0;R2];

%----------------------------;
% U.S.(1871-1945);
%----------------------------;

T = size(DP_3,1);

%Raw data;
y=RET_3;
x=[ones(T-1,1) DP_3(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,3)=[b(2,1);tb(2,1);0;R2];

y=DG_3;
x=[ones(T-1,1) DP_3(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,3)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=ret_3;
x=[ones(T-1,1) dp_3(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,3)=[b(2,1);tb(2,1);0;R2];

y=dg_3;
x=[ones(T-1,1) dp_3(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,3)=[b(2,1);tb(2,1);0;R2];

%----------------------------;
% U.S.(1945-2015);
%----------------------------;

T = size(DP_4,1);

%Raw data;
y=RET_4;
x=[ones(T-1,1) DP_4(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,4)=[b(2,1);tb(2,1);0;R2];

y=DG_4;
x=[ones(T-1,1) DP_4(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,4)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=ret_4;
x=[ones(T-1,1) dp_4(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,4)=[b(2,1);tb(2,1);0;R2];

y=dg_4;
x=[ones(T-1,1) dp_4(1:T-1)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,4)=[b(2,1);tb(2,1);0;R2];

%---------------------------------------;
% Full-sample period: short (1700-2015);
%---------------------------------------;

T = size([DP_1_s;DP_2;DP_34],1);

%Raw data;
y=[RET_1_s;RET_2;RET_34];
x=[ones(T-3,1) [DP_1_s(1:end-1);DP_2(1:end-1);DP_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,5)=[b(2,1);tb(2,1);0;R2];

y=[DG_1_s;DG_2;DG_34];
x=[ones(T-3,1) [DP_1_s(1:end-1);DP_2(1:end-1);DP_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,5)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=[ret_1_s;ret_2;ret_34];
x=[ones(T-3,1) [dp_1_s(1:end-1);dp_2(1:end-1);dp_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,5)=[b(2,1);tb(2,1);0;R2];

y=[dg_1_s;dg_2;dg_34];
x=[ones(T-3,1) [dp_1_s(1:end-1);dp_2(1:end-1);dp_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,5)=[b(2,1);tb(2,1);0;R2];

%---------------------------------;
% Full-sample period (1629-2015);
%---------------------------------;

T = size([DP_1;DP_2;DP_34],1);

%Raw data;
y=[RET_1;RET_2;RET_34];
x=[ones(T-3,1) [DP_1(1:end-1);DP_2(1:end-1);DP_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(1:4,6)=[b(2,1);tb(2,1);0;R2];

y=[DG_1;DG_2;DG_34];
x=[ones(T-3,1) [DP_1(1:end-1);DP_2(1:end-1);DP_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(5:8,6)=[b(2,1);tb(2,1);0;R2];

%Logs;
y=[ret_1;ret_2;ret_34];
x=[ones(T-3,1) [dp_1(1:end-1);dp_2(1:end-1);dp_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(9:12,6)=[b(2,1);tb(2,1);0;R2];

y=[dg_1;dg_2;dg_34];
x=[ones(T-3,1) [dp_1(1:end-1);dp_2(1:end-1);dp_34(1:end-1)]];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_2(13:16,6)=[b(2,1);tb(2,1);0;R2];

%-------------------------------------------------------------------------;
% Sub-sample interaction: Arithmetic variables;
%-------------------------------------------------------------------------;

DP=[DP_1(1:end-1);DP_2(1:end-1);DP_3(1:end-1);DP_4(1:end-1)];
T=size(DP,1);

%Neth/UK: Long;
D=[ones(size(DP_1,1)-1,1);zeros(size(DP_2,1)-1,1);zeros(size(DP_3,1)-1,1);zeros(size(DP_4,1)-1,1);];

y=[RET_1;RET_2;RET_3;RET_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(3,1)=tb(4,1);

y=[DG_1;DG_2;DG_3;DG_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(7,1)=tb(4,1);

%UK;
D=[zeros(size(DP_1,1)-1,1);ones(size(DP_2,1)-1,1);zeros(size(DP_3,1)-1,1);zeros(size(DP_4,1)-1,1);];

y=[RET_1;RET_2;RET_3;RET_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(3,2)=tb(4,1);

y=[DG_1;DG_2;DG_3;DG_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(7,2)=tb(4,1);

%US: Pre 1945;
D=[zeros(size(DP_1,1)-1,1);zeros(size(DP_2,1)-1,1);ones(size(DP_3,1)-1,1);zeros(size(DP_4,1)-1,1);];

y=[RET_1;RET_2;RET_3;RET_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(3,3)=tb(4,1);

y=[DG_1;DG_2;DG_3;DG_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(7,3)=tb(4,1);

%US: Post 1945;
D=[zeros(size(DP_1,1)-1,1);zeros(size(DP_2,1)-1,1);zeros(size(DP_3,1)-1,1);ones(size(DP_4,1)-1,1);];

y=[RET_1;RET_2;RET_3;RET_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(3,4)=tb(4,1);

y=[DG_1;DG_2;DG_3;DG_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(7,4)=tb(4,1);

%Full sample short: 1700-2015;
D=[zeros(size(DP_1,1)-size(DP_1_s,1),1);ones(size(DP_1_s,1)-1,1);ones(size(DP_2,1)-1,1);ones(size(DP_3,1)-1,1);ones(size(DP_4,1)-1,1);];

y=[RET_1;RET_2;RET_3;RET_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(3,5)=tb(4,1);

y=[DG_1;DG_2;DG_3;DG_4];
x=[ones(T,1) D DP DP.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(7,5)=tb(4,1);

%-------------------------------------------------------------------------;
% Sub-sample interactions: Log variables;
%-------------------------------------------------------------------------;

dp=[dp_1(1:end-1);dp_2(1:end-1);dp_3(1:end-1);dp_4(1:end-1)];
T=size(dp,1);

%Neth/UK: Long;
D=[ones(size(dp_1,1)-1,1);zeros(size(dp_2,1)-1,1);zeros(size(dp_3,1)-1,1);zeros(size(dp_4,1)-1,1);];

y=[ret_1;ret_2;ret_3;ret_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(11,1)=tb(4,1);

y=[dg_1;dg_2;dg_3;dg_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(15,1)=tb(4,1);

%UK;
D=[zeros(size(dp_1,1)-1,1);ones(size(dp_2,1)-1,1);zeros(size(dp_3,1)-1,1);zeros(size(dp_4,1)-1,1);];

y=[ret_1;ret_2;ret_3;ret_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(11,2)=tb(4,1);

y=[dg_1;dg_2;dg_3;dg_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(15,2)=tb(4,1);

%US: Pre 1945;
D=[zeros(size(dp_1,1)-1,1);zeros(size(dp_2,1)-1,1);ones(size(dp_3,1)-1,1);zeros(size(dp_4,1)-1,1);];

y=[ret_1;ret_2;ret_3;ret_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(11,3)=tb(4,1);

y=[dg_1;dg_2;dg_3;dg_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(15,3)=tb(4,1);

%US: Post 1945;
D=[zeros(size(dp_1,1)-1,1);zeros(size(dp_2,1)-1,1);zeros(size(dp_3,1)-1,1);ones(size(dp_4,1)-1,1);];

y=[ret_1;ret_2;ret_3;ret_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(11,4)=tb(4,1);

y=[dg_1;dg_2;dg_3;dg_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(15,4)=tb(4,1);

%Full sample short: 1700-2015;
D=[zeros(size(dp_1,1)-size(dp_1_s,1),1);ones(size(dp_1_s,1)-1,1);ones(size(dp_2,1)-1,1);ones(size(dp_3,1)-1,1);ones(size(dp_4,1)-1,1);];

y=[ret_1;ret_2;ret_3;ret_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(11,5)=tb(4,1);

y=[dg_1;dg_2;dg_3;dg_4];
x=[ones(T,1) D dp dp.*D];
[b,b_std,tb,R2,AR2]=olsnw(y,x,1,1);
Tab_2(15,5)=tb(4,1);
Tab_2([3 7 11 15],6)=[NaN NaN NaN NaN];

Tab_2