%-------------------------------------------------------------------------;
% Table 6: Summary statistics for business cycle variation
% Results are in Tab_6.
%-------------------------------------------------------------------------;

clear all;
clc;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Data on recessions is available from 1700 onwards. No dividend smoothing
%applied to this period;

data_s=data((data(:,1)>=1700 & data(:,1)<=1812),:);
dates_s=data(:,1);

%Prices and dividends;
P=data_s(:,2+a); 
D=data_s(:,3+a);

%Define variables. 
RET_1_s=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_1_s=D(2:end)./D(1:end-1)-1;
DP_1_s=D(1:end)./P(1:end);

ret_1_s=log(1+RET_1_s);
dg_1_s=log(1+DG_1_s);
dp_1_s=log(DP_1_s);

recession_1_s=data_s(1:end,7);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

ret_2=log(1+RET_2);
dg_2=log(1+DG_2);
dp_2=log(DP_2);

recession_2=data(1:end,7);

%----------------------;
% U.S. early 1871-1945
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=1945),:);
dates_3=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_3=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_3=(D(2:end))./(D(1:end-1))-1;
DP_3=(D(1:end))./(P(1:end));

ret_3=log(1+RET_3);
dg_3=log(1+DG_3);
dp_3=log(DP_3);

recession_3=data(1:end,7);

%------------------------;
% U.S. recent: 1945-2015
%------------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1945 & data(:,1)<=2015),:);
dates_4=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_4=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_4=(D(2:end))./(D(1:end-1))-1;
DP_4=(D(1:end))./(P(1:end));

ret_4=log(1+RET_4);
dg_4=log(1+DG_4);
dp_4=log(DP_4);

recession_4=data(1:end,7);

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

ret_34=log(1+RET_34);
dg_34=log(1+DG_34);
dp_34=log(DP_34);

recession_34=data(1:end,7);

%----------------------------------------------------------;
% Summary statistics for returns and dividend growth rates
%----------------------------------------------------------;

%Set up data for each period so that returns and dividend growth rates 
%are aligned with recessions and the current dividend-to-price ratio;

%Arithmetic real variables;
y_1_s=[RET_1_s DG_1_s DP_1_s(2:end) recession_1_s(2:end)];
y_2=[RET_2 DG_2 DP_2(2:end) recession_2(2:end)];
y_3=[RET_3 DG_3 DP_3(2:end) recession_3(2:end)];
y_4=[RET_4 DG_4 DP_4(2:end) recession_4(2:end)];
y_34=[RET_34 DG_34 DP_34(2:end) recession_34(2:end)];

%----------------;
% 1700-1945;
%----------------;

y=[y_1_s;y_2;y_3];

%Take out recessions;
a=y(:,4)==1;
y_r=y(a,:);

%Take out expansions;
a=y(:,4)==0;
y_e=y(a,:);

Tab_6([1 2 4 5 7 8],1)=[mean(y_r(:,1));std(y_r(:,1));mean(y_r(:,2));std(y_r(:,2));mean(y_r(:,3));std(y_r(:,3))];
Tab_6([1 2 4 5 7 8],2)=[mean(y_e(:,1));std(y_e(:,1));mean(y_e(:,2));std(y_e(:,2));mean(y_e(:,3));std(y_e(:,3))];

%Test that two independent samples come from distributions with equal
%means;
[h,p,ci,stats_r] = ttest2(y_r(:,1),y_e(:,1),0.05,'both','unequal');
[h,p,ci,stats_dg] = ttest2(y_r(:,2),y_e(:,2),0.05,'both','unequal');
[h,p,ci,stats_dp] = ttest2(y_r(:,3),y_e(:,3),0.05,'both','unequal');

Tab_6([3 6 9],1)=[stats_r.tstat stats_dg.tstat stats_dp.tstat];
Tab_6([3 6 9],2)=ones(3,1)*NaN;
Tab_6(10,[1 2])=[size(y_r,1) size(y_e,1)];

%----------------;
% 1945-2015;
%----------------;

y=y_4;

%Take out recessions;
a=y(:,4)==1;
y_r=y(a,:);

%Take out expansions;
a=y(:,4)==0;
y_e=y(a,:);

Tab_6([1 2 4 5 7 8],3)=[mean(y_r(:,1));std(y_r(:,1));mean(y_r(:,2));std(y_r(:,2));mean(y_r(:,3));std(y_r(:,3))];
Tab_6([1 2 4 5 7 8],4)=[mean(y_e(:,1));std(y_e(:,1));mean(y_e(:,2));std(y_e(:,2));mean(y_e(:,3));std(y_e(:,3))];

%Test that two independent samples come from distributions with equal
%means;
[h,p,ci,stats_r] = ttest2(y_r(:,1),y_e(:,1),0.05,'both','unequal');
[h,p,ci,stats_dg] = ttest2(y_r(:,2),y_e(:,2),0.05,'both','unequal');
[h,p,ci,stats_dp] = ttest2(y_r(:,3),y_e(:,3),0.05,'both','unequal');

Tab_6([3 6 9],3)=[stats_r.tstat stats_dg.tstat stats_dp.tstat];
Tab_6([3 6 9],4)=ones(3,1)*NaN;
Tab_6(10,[3 4])=[size(y_r,1) size(y_e,1)];

%----------------;
% 1700-2015;
%----------------;

y=[y_1_s;y_2;y_34];

%Take out recessions;
a=y(:,4)==1;
y_r=y(a,:);

%Take out expansions;
a=y(:,4)==0;
y_e=y(a,:);

Tab_6([1 2 4 5 7 8],5)=[mean(y_r(:,1));std(y_r(:,1));mean(y_r(:,2));std(y_r(:,2));mean(y_r(:,3));std(y_r(:,3))];
Tab_6([1 2 4 5 7 8],6)=[mean(y_e(:,1));std(y_e(:,1));mean(y_e(:,2));std(y_e(:,2));mean(y_e(:,3));std(y_e(:,3))];

%Test that two independent samples come from distributions with equal
%means;
[h,p,ci,stats_r] = ttest2(y_r(:,1),y_e(:,1),0.05,'both','unequal');
[h,p,ci,stats_dg] = ttest2(y_r(:,2),y_e(:,2),0.05,'both','unequal');
[h,p,ci,stats_dp] = ttest2(y_r(:,3),y_e(:,3),0.05,'both','unequal');

Tab_6([3 6 9],5)=[stats_r.tstat stats_dg.tstat stats_dp.tstat];
Tab_6([3 6 9],6)=ones(3,1)*NaN;
Tab_6(10,[5 6])=[size(y_r,1) size(y_e,1)];

%----------------;
%Display results;
%----------------;

%Express the main variables in percentages;

Tab_6([1;2;4;5;7;8],:)=Tab_6([1;2;4;5;7;8],:)*100
