%-------------------------------------------------------------------------;
% Table 7: Regressions for business cycle variation 
% Results are in Tab_7.
%-------------------------------------------------------------------------;

clear all;
clc;

% '1' - Netherlands/U.K. period: 1629-1812;
% '2' - U.K. period; 1813-1870;
% '3' - U.S. early: 1871:1945;
% '4' - U.S. recent: 1945-2015;
% '34' - Combined U.S. period: 1871-2015;

%Choose nominal or real data;
a=2; %0 for nominal, 2 for real;

%-------------------;
% Netherlands/U.K.;
%-------------------;

filename='Data_Netherlands_UK_1602_1812.xls';
data=xlsread(filename);

%Data on recessions is available from 1700 onwards. No dividend smoothing
%applied to this period;

data_s=data((data(:,1)>=1700 & data(:,1)<=1812),:);
dates_s=data(:,1);

%Prices and dividends;
P=data_s(:,2+a); 
D=data_s(:,3+a);

%Define variables. 
RET_1_s=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_1_s=D(2:end)./D(1:end-1)-1;
DP_1_s=D(1:end)./P(1:end);

ret_1_s=log(1+RET_1_s);
dg_1_s=log(1+DG_1_s);
dp_1_s=log(DP_1_s);

recession_1_s=data_s(1:end,7);

%-------------------;
% U.K.;
%-------------------;

filename='Data_UK_1813_1870.xls';
data=xlsread(filename);

%Determine time period: 1813-1870;
data=data((data(:,1)>=1813 & data(:,1)<=1870),:);
dates_2=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a); 

%Define variables;
RET_2=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_2=(D(2:end))./(D(1:end-1))-1;
DP_2=(D(1:end))./(P(1:end));

ret_2=log(1+RET_2);
dg_2=log(1+DG_2);
dp_2=log(DP_2);

recession_2=data(1:end,7);

%----------------------;
% U.S. early 1871-1945
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=1945),:);
dates_3=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_3=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_3=(D(2:end))./(D(1:end-1))-1;
DP_3=(D(1:end))./(P(1:end));

ret_3=log(1+RET_3);
dg_3=log(1+DG_3);
dp_3=log(DP_3);

recession_3=data(1:end,7);

%------------------------;
% U.S. recent: 1945-2015
%------------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1945 & data(:,1)<=2015),:);
dates_4=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_4=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_4=(D(2:end))./(D(1:end-1))-1;
DP_4=(D(1:end))./(P(1:end));

ret_4=log(1+RET_4);
dg_4=log(1+DG_4);
dp_4=log(DP_4);

recession_4=data(1:end,7);

%----------------------;
% U.S. Full: 1871-2015
%----------------------;

filename='Data_US_1871_2015.xls';
data=xlsread(filename);

%Determine time period: 1871-2015;
data=data((data(:,1)>=1871 & data(:,1)<=2015),:);
dates_34=data(:,1);

%Prices and dividends;
P=data(:,2+a); 
D=data(:,3+a);

%Define variables;
RET_34=(P(2:end)+D(2:end))./(P(1:end-1))-1;
DG_34=(D(2:end))./(D(1:end-1))-1;
DP_34=(D(1:end))./(P(1:end));

ret_34=log(1+RET_34);
dg_34=log(1+DG_34);
dp_34=log(DP_34);

recession_34=data(1:end,7);

%-------------------------------------------------------------------------;
%Set up the data for each period. Recession dummy is aligned with lagged
%dividend-to-price ratio;
%-------------------------------------------------------------------------;

y_1_s=[ret_1_s dg_1_s dp_1_s(2:end) recession_1_s(2:end) dp_1_s(1:end-1) recession_1_s(1:end-1)];
y_2=[ret_2 dg_2 dp_2(2:end) recession_2(2:end) dp_2(1:end-1) recession_2(1:end-1)];
y_3=[ret_3 dg_3 dp_3(2:end) recession_3(2:end) dp_3(1:end-1) recession_3(1:end-1)];
y_4=[ret_4 dg_4 dp_4(2:end) recession_4(2:end) dp_4(1:end-1) recession_4(1:end-1)];
y_34=[ret_34 dg_34 dp_34(2:end) recession_34(2:end) dp_34(1:end-1) recession_34(1:end-1)];

%-----------------------------;
% 1700-1945;
%-----------------------------;

y_all=[y_1_s;y_2;y_3];

%Rho
mean_dp=mean([dp_1_s;dp_2;dp_3]);
rho=exp(-mean_dp)/(1+exp(-mean_dp));

T=size(y_all,1);

%Dividend-to-price ratio as the only predictor;

x=[ones(T,1) y_all(:,5)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,1)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,1)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,1)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Long-run coefficients;
Tab_7(21,1)=Tab_7(1,1)/(1-rho*Tab_7(11,1));
Tab_7(22,1)=NaN;
Tab_7(23,1)=Tab_7(6,1)/(1-rho*Tab_7(11,1));
Tab_7(24,1)=NaN;

%Dividend-to-price ratio plus recession dummy;

x=[ones(T,1) y_all(:,5) y_all(:,6)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,2)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,2)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,2)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Recession;
y=y_all(:,4);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(16:20,2)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Long-run coefficients;
Phi=[Tab_7(11,2) Tab_7(13,2); Tab_7(16,2) Tab_7(18,2)];
B=[Tab_7(1,2) Tab_7(3,2); Tab_7(6,2) Tab_7(8,2)];
LR=B/(eye(2)-rho*Phi);
Tab_7(21:22,2)=LR(1,1:2);
Tab_7(23:24,2)=LR(2,1:2);

%Persistence of recessions;
y=y_all(:,4);
x=[ones(T,1) y_all(:,6)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(18:20,1)=[b(2,1);tb(2,1);R2];
Tab_7(16:17,1)=NaN*ones(2,1);

%-----------------------------;
% 1945-2015;
%-----------------------------;

y_all=y_4;

%Rho
mean_dp=mean(dp_4);
rho=exp(-mean_dp)/(1+exp(-mean_dp));

T=size(y_all,1);

%Dividend-to-price ratio as the only predictor;

x=[ones(T,1) y_all(:,5)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,3)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,3)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,3)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Long-run coefficients;
Tab_7(21,3)=Tab_7(1,3)/(1-rho*Tab_7(11,3));
Tab_7(22,3)=NaN;
Tab_7(23,3)=Tab_7(6,3)/(1-rho*Tab_7(11,3));
Tab_7(24,3)=NaN;

%Dividend-to-price ratio plus recession dummy;

x=[ones(T,1) y_all(:,5) y_all(:,6)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,4)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,4)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,4)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Recession;
y=y_all(:,4);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(16:20,4)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Long-run coefficients;
Phi=[Tab_7(11,4) Tab_7(13,4); Tab_7(16,4) Tab_7(18,4)];
B=[Tab_7(1,4) Tab_7(3,4); Tab_7(6,4) Tab_7(8,4)];
LR=B/(eye(2)-rho*Phi);
Tab_7(21:22,4)=LR(1,1:2);
Tab_7(23:24,4)=LR(2,1:2);

%Persistence of recessions;
y=y_all(:,4);
x=[ones(T,1) y_all(:,6)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(18:20,3)=[b(2,1);tb(2,1);R2];
Tab_7(16:17,3)=NaN*ones(2,1);

%-----------------------------;
% 1700-2015;
%-----------------------------;

y_all=[y_1_s;y_2;y_34];

%Rho
mean_dp=mean([dp_1_s;dp_2;dp_34]);
rho=exp(-mean_dp)/(1+exp(-mean_dp));

T=size(y_all,1);

%Dividend-to-price ratio as the only predictor;

x=[ones(T,1) y_all(:,5)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,5)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,5)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,5)=[b(2,1);tb(2,1);NaN;NaN;R2];

%Long-run coefficients;
Tab_7(21,5)=Tab_7(1,5)/(1-rho*Tab_7(11,5));
Tab_7(22,5)=NaN;
Tab_7(23,5)=Tab_7(6,5)/(1-rho*Tab_7(11,5));
Tab_7(24,5)=NaN;

%Dividend-to-price ratio plus recession dummy;

x=[ones(T,1) y_all(:,5) y_all(:,6)];

%Returns;
y=y_all(:,1);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(1:5,6)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend growth;
y=y_all(:,2);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(6:10,6)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Dividend-price ratio;
y=y_all(:,3);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(11:15,6)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Recession;
y=y_all(:,4);
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(16:20,6)=[b(2,1);tb(2,1);b(3,1);tb(3,1);R2];

%Long-run coefficients;
Phi=[Tab_7(11,6) Tab_7(13,6); Tab_7(16,6) Tab_7(18,6)];
B=[Tab_7(1,6) Tab_7(3,6); Tab_7(6,6) Tab_7(8,6)];
LR=B/(eye(2)-rho*Phi);
Tab_7(21:22,6)=LR(1,1:2);
Tab_7(23:24,6)=LR(2,1:2);

%Persistence of recessions;
y=y_all(:,4);
x=[ones(T,1) y_all(:,6)];
[b,b_std,tb,R2,AR2,error]=olsnw(y,x,1,1);
Tab_7(18:20,5)=[b(2,1);tb(2,1);R2];
Tab_7(16:17,5)=NaN*ones(2,1);

%Display results;
Tab_7














